local function checkCollision(img1,x1,y1,w1,h1, img2,x2,y2,w2,h2)

    -- Calculate the coordinates of the corners of the two objects
    local left1, top1, right1, bottom1 = x1, y1, x1 + w1, y1 + h1
    local left2, top2, right2, bottom2 = x2, y2, x2 + w2, y2 + h2

    -- Check if there is an intersection between the two objects

    if right1 > left2 and left1 < right2 and bottom1 > top2 and top1 < bottom2 then

        -- Calculate the intersection area between the two objects
        local intersectionLeft = math.max(left1, left2)
        local intersectionTop = math.max(top1, top2)
        local intersectionRight = math.min(right1, right2)
        local intersectionBottom = math.min(bottom1, bottom2)

        local floor = math.floor

        -- Iterate through all pixels in the intersection area
        for x = intersectionLeft, intersectionRight-1 do
            for y = intersectionTop, intersectionBottom-1 do

                -- Calculate pixel coordinates in both images
                local playerPixelX, playerPixelY = floor(x-x1), floor(y - y1)
                local obstaclePixelX, obstaclePixelY = floor(x-x2), floor(y-y2)

                -- Check if both pixels are opaque
                local _,_,_,a1 = img1:getPixel(playerPixelX, playerPixelY)
                local _,_,_,a2 = img2:getPixel(obstaclePixelX, obstaclePixelY)

                if a1 > 0 and a2 > 0 then return true end

            end
        end

    end

    return false

end


local player = {}
local obstacle = {}

function love.load()

    player.image_data = love.image.newImageData("player.png")
    obstacle.image_data = love.image.newImageData("obstacle.png")

    player.image = love.graphics.newImage(player.image_data)
    obstacle.image = love.graphics.newImage(obstacle.image_data)

    player.x, player.y = 100, 100
    obstacle.x, obstacle.y = 200, 200

    player.w, player.h = player.image:getDimensions()
    obstacle.w, obstacle.h = obstacle.image:getDimensions()

end

function love.update(dt)

    if love.keyboard.isDown("left") then
        player.x = player.x - 100 * dt
    end

    if love.keyboard.isDown("right") then
        player.x = player.x + 100 * dt
    end

    if love.keyboard.isDown("up") then
        player.y = player.y - 100 * dt
    end

    if love.keyboard.isDown("down") then
        player.y = player.y + 100 * dt
    end

    if checkCollision(
        player.image_data, player.x, player.y, player.w, player.h,
        obstacle.image_data, obstacle.x, obstacle.y, obstacle.w, obstacle.h
    ) then
        print("Collision!")
    end

end

function love.draw()
  love.graphics.draw(player.image, player.x, player.y)
  love.graphics.draw(obstacle.image, obstacle.x, obstacle.y)
end

